==> aws-cdk.aws-apigatewayv2-authorizers-alpha-2.24.1a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.userPoolClients))
            require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_cognito_IUserPoolClient(p.userPoolClients);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.responseTypes))
            _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p.responseTypes);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer };

==> aws-cdk.aws-apigatewayv2-authorizers-alpha-2.38.1a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.userPoolClients))
            require("aws-cdk-lib/.warnings.jsii.js").aws_cdk_lib_aws_cognito_IUserPoolClient(p.userPoolClients);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.responseTypes))
            _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType(p.responseTypes);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer(p) {
}
function _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketIamAuthorizer(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_alpha_WebSocketIamAuthorizer };
